@@ -3,7 +3,7 @@ package Task::Digest;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;
 
 
@@ -37,6 +37,8 @@ cryptographic message digests.
 
 =item * L<Digest::Fugue>
 
+=item * L<Digest::GOST>
+
 =item * L<Digest::Groestl>
 
 =item * L<Digest::Hamsi>
@@ -83,69 +85,70 @@ This distribution contains a benchmarking script which compares the
 available message digest algorithms. These are the results on a MacBook 2GHz
 Core 2 Duo (64-bit) with Perl 5.12.2, using a message size of 1KB:
 
-    md4          287826/s   281 MB/s
+    md4          295821/s   289 MB/s
     md5          245759/s   240 MB/s
-    skein_512    222695/s   217 MB/s
-    bmw_384      216392/s   211 MB/s
-    bmw_512      210823/s   206 MB/s
-    skein_256    196495/s   192 MB/s
-    blake_384    151837/s   148 MB/s
+    bmw_384      217211/s   212 MB/s
+    skein_512    216392/s   211 MB/s
+    bmw_512      215039/s   210 MB/s
+    skein_256    190300/s   186 MB/s
+    blake_384    156392/s   153 MB/s
     blake_512    150312/s   147 MB/s
-    bmw_224      132741/s   130 MB/s
-    bmw_256      132740/s   130 MB/s
-    blake_224    121663/s   119 MB/s
-    blake_256    120302/s   117 MB/s
-    sha_sha_1    115924/s   113 MB/s
-    skein_1024   112733/s   110 MB/s
-    sha1_sha_1   106192/s   104 MB/s
+    bmw_256      132741/s   130 MB/s
+    bmw_224      132740/s   130 MB/s
+    blake_256    120470/s   118 MB/s
+    blake_224    120302/s   117 MB/s
+    sha_sha_1    114840/s   112 MB/s
+    skein_1024   111347/s   109 MB/s
+    sha1_sha_1   103384/s   101 MB/s
     shabal_512    97303/s    95 MB/s
-    shabal_384    97303/s    95 MB/s
     shabal_224    97303/s    95 MB/s
+    shabal_384    96376/s    94 MB/s
     shabal_256    96376/s    94 MB/s
+    sha_256       76799/s    75 MB/s
     sha_512       76560/s    75 MB/s
-    sha_256       75918/s    74 MB/s
-    sha_384       73770/s    72 MB/s
-    sha_224       73080/s    71 MB/s
-    keccak_224    59650/s    58 MB/s
-    keccak_256    59076/s    58 MB/s
+    sha_384       73080/s    71 MB/s
+    sha_224       72404/s    71 MB/s
+    keccak_256    60703/s    59 MB/s
+    keccak_224    60703/s    59 MB/s
     luffa_256     54613/s    53 MB/s
-    luffa_224     54613/s    53 MB/s
-    ripemd_160    51121/s    50 MB/s
-    keccak_384    48872/s    48 MB/s
-    md6_224       47287/s    46 MB/s
-    shavite3_256  47287/s    46 MB/s
+    luffa_224     54098/s    53 MB/s
+    ripemd_160    51200/s    50 MB/s
+    keccak_384    49777/s    49 MB/s
+    md6_224       47733/s    47 MB/s
+    fugue_256     47287/s    46 MB/s
+    fugue_224     47287/s    46 MB/s
     shavite3_224  47287/s    46 MB/s
-    fugue_256     46849/s    46 MB/s
-    fugue_224     46849/s    46 MB/s
+    shavite3_256  45997/s    45 MB/s
     md6_256       44660/s    44 MB/s
     groestl_224   41353/s    40 MB/s
     groestl_256   41353/s    40 MB/s
-    luffa_384     40194/s    39 MB/s
-    echo_256      38745/s    38 MB/s
-    echo_224      38745/s    38 MB/s
-    md6_384       36202/s    35 MB/s
-    keccak_512    33811/s    33 MB/s
-    fugue_384     31508/s    31 MB/s
-    simd_224      30632/s    30 MB/s
-    shavite3_512  30075/s    29 MB/s
-    md6_512       30075/s    29 MB/s
-    shavite3_384  30075/s    29 MB/s
-    luffa_512     29538/s    29 MB/s
-    cubehash_224  27927/s    27 MB/s
+    luffa_384     40193/s    39 MB/s
+    echo_256      39097/s    38 MB/s
+    echo_224      39009/s    38 MB/s
+    md6_384       36540/s    36 MB/s
+    keccak_512    34132/s    33 MB/s
+    fugue_384     30919/s    30 MB/s
+    md6_512       30351/s    30 MB/s
+    simd_256      30075/s    29 MB/s
+    simd_224      30075/s    29 MB/s
+    luffa_512     29805/s    29 MB/s
+    shavite3_384  29537/s    29 MB/s
+    shavite3_512  29020/s    28 MB/s
+    gost          28980/s    28 MB/s
+    cubehash_256  27927/s    27 MB/s
     cubehash_512  27926/s    27 MB/s
+    cubehash_224  27926/s    27 MB/s
     cubehash_384  27926/s    27 MB/s
-    cubehash_256  27926/s    27 MB/s
-    simd_256      27117/s    26 MB/s
-    hamsi_256     24889/s    24 MB/s
-    hamsi_224     24888/s    24 MB/s
-    fugue_512     23424/s    23 MB/s
-    whirlpool     23424/s    23 MB/s
+    hamsi_224     24889/s    24 MB/s
+    hamsi_256     24888/s    24 MB/s
+    fugue_512     23209/s    23 MB/s
+    whirlpool     23209/s    23 MB/s
     echo_512      21154/s    21 MB/s
-    echo_384      21154/s    21 MB/s
+    echo_384      20958/s    20 MB/s
     groestl_384   17935/s    18 MB/s
     groestl_512   17935/s    18 MB/s
-    simd_512      17612/s    17 MB/s
-    simd_384      17612/s    17 MB/s
+    simd_384      17568/s    17 MB/s
+    simd_512      17066/s    17 MB/s
     jh_384        14221/s    14 MB/s
     jh_512        14221/s    14 MB/s
     jh_256        14221/s    14 MB/s
@@ -154,12 +157,12 @@ Core 2 Duo (64-bit) with Perl 5.12.2, using a message size of 1KB:
     hamsi_512      7657/s     7 MB/s
     md2            5338/s     5 MB/s
     perl_sha_1      175/s  0.17 MB/s
-    perl_sha_224    129/s  0.13 MB/s
-    perl_sha_256    129/s  0.13 MB/s
+    perl_sha_256    128/s  0.12 MB/s
+    perl_sha_224    127/s  0.12 MB/s
+    perl_md4         76/s  0.07 MB/s
     perl_md5         75/s  0.07 MB/s
-    perl_md4         75/s  0.07 MB/s
-    perl_sha_384     62/s  0.06 MB/s
     perl_sha_512     61/s  0.06 MB/s
+    perl_sha_384     61/s  0.06 MB/s
 
 =head1 SEE ALSO
 
